import { Instance, Method, ResponseOption, VisitOptions } from "formjs-core";
import { AxiosResponse } from "axios";
import { ObjectSchema } from "yup";
interface FormProps<TForm> {
    isDirty: boolean;
    errors: Record<keyof TForm, string>;
    hasErrors: boolean;
    processing: boolean;
    data(): TForm;
    transform(callback: (data: TForm) => object): this;
    defaults(): this;
    defaults(field: keyof TForm, value: string): this;
    defaults(fields: Record<keyof TForm, string>): this;
    reset(...fields: (keyof TForm)[]): this;
    setError(field: keyof TForm, value: string): this;
    setError(errors: Record<keyof TForm, string>): this;
    clearErrors(...fields: (keyof TForm)[]): this;
    validate(): void;
    validate(field: keyof TForm): void;
    submit(method: Method, url: string, options?: Partial<VisitOptions>): void;
    get(url: string, options?: Partial<VisitOptions>): void;
    post(url: string, options?: Partial<VisitOptions>): void;
    put(url: string, options?: Partial<VisitOptions>): void;
    delete(url: string, options?: Partial<VisitOptions>): void;
    call(callback: () => Promise<AxiosResponse<any, any>>, options?: Partial<ResponseOption>): void;
}
type Form<TForm> = TForm & FormProps<TForm>;
type FormOptions<TForm> = {
    schema?: ObjectSchema<Record<keyof TForm, string>>;
    instance?: Instance;
};
export default function useForm<TForm>(data: TForm): Form<TForm>;
export default function useForm<TForm>(data: TForm, options: FormOptions<TForm>): Form<TForm>;
export {};
